==> v1.4.0.zip: user_saml/l10n/es_AR.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Guardado",
    "X.509 certificate of the Service Provider" : "certificado X.509 del Proveedor de Servicio",
    "Private key of the Service Provider" : "Llave privada del Proveedor de Servicio",
    "Indicates that the nameID of the <samlp:logoutRequest> sent by this SP will be encrypted." : "Indica que el nameID de <samlp:logoutRequest> enviado por este SP será encriptado. ",
    "Indicates whether the <samlp:AuthnRequest> messages sent by this SP will be signed. [Metadata of the SP will offer this info]" : "Indica si los mensajes <samlp:AuthnRequest> enviados por este SP serán firmados. [Los metadatos del SP proporcionarán esta información]",
    "Indicates whether the  <samlp:logoutRequest> messages sent by this SP will be signed." : "Indica si los mensjaes <samlp:logoutRequest> enviados por este SP serán firmados. ",
    "Indicates whether the  <samlp:logoutResponse> messages sent by this SP will be signed." : "Indica is los mensajes <samlp:logoutResponse> enviados por este SP serán firmados. ",
    "Whether the metadata should be signed." : "Si los metadatos deben ser firmados o no. ",
    "Indicates a requirement for the <samlp:Response>, <samlp:LogoutRequest> and <samlp:LogoutResponse> elements received by this SP to be signed." : "Indica un requerimiento para que los elementos recibidos <samlp:Response>, <samlp:LogoutRequest> y <samlp:LogoutResponse> por este SP sean firmados. ",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be signed. [Metadata of the SP will offer this info]" : "Indica un requerimientos para que los elementos recibidos <saml:Assertion> por este SP para ser firmados. [Los metadatos del SP proporcionarán esta información]",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be encrypted." : "Indica un requerimiento para que los elelemtnos recibidos <saml:Assertion> de este SP sean encriptados. ",
    " Indicates a requirement for the NameID element on the SAMLResponse received by this SP to be present." : "Indica un requerimiento para que el elemento NameID en la SAMLResponse recibida por este SP esté presente. ",
    "Indicates a requirement for the NameID received by this SP to be encrypted." : "Indica que un requerimiento para el NameID recibido por este SP está encriptado.",
    "ADFS URL-Encodes SAML data as lowercase, and the toolkit by default uses uppercase. Enable for ADFS compatibility on signature verification." : "ADFS URL-Codifica los datos SAML como minúsculas, y el juego de herramientas usa mayúsculas por defecto. Habilite para tener compatibilidad con ADFS en la verificacón de la firma.",
    "Attribute to map the UID to." : "Atributo a mapear al UID.",
    "Attribute to map the displayname to." : "Atributo a mapear a displayname. ",
    "Attribute to map the email address to." : "Atributo a mapear a email address.",
    "Use SAML auth for the %s desktop clients (requires user re-authentication)" : "Favor de usar autenticación SAML para los %s clientes de escritorio (se requiere volver a autenticar)",
    "SSO & SAML authentication" : "Autenticación SSO & SAML",
    "Open documentation" : "Abrir documentación",
    "Please choose whether you want to authenticate using the SAML provider built-in in Nextcloud or whether you want to authenticate against an environment variable." : "Favor de seleccionar si usted desdea autenticarse usando el proveedor integrado SAML de Nextcloud o si desdea autenticarse contra una variable de ambiente.  ",
    "Use built-in SAML authentication" : "Usar autenticación SAML integrada",
    "Use environment variable" : "Usar la variable de ambiente",
    "Make sure to configure an administrative user that can access the instance via SSO. Logging-in with your regular %s account won't be possible anymore." : "Asegurese de configurar un usuario administrativo que tenga acceso a la instancia mediante SSO. Iniciar sesión con su cuenta regular %s no será más posible. ",
    "General" : "General",
    "Service Provider Data" : "Datos del Proveedor de Servicio",
    "If your Service Provider should use certificates you can optionally specify them here." : "Si su Proveedor de Servicio debe usar certificados, usted puede especificarlos opcionalmente desde aquí.",
    "Identity Provider Data" : "Datos del Proveedor de Identidad",
    "Configure your IdP settings here." : "Configure los configuraciones de IdP aquí. ",
    "Identifier of the IdP entity (must be a URI)" : "Identificador de la entidad IdP (debe ser un URI)",
    "URL Target of the IdP where the SP will send the Authentication Request Message" : "URL Destino del IdP donde el SP enviará automaticamente el Mensaje de Solicitud de Autenticación",
    "URL Location of the IdP where the SP will send the SLO Request" : "Ubicación del URL del IdP donde el SP enviará la Solicitud SLO",
    "Public X.509 certificate of the IdP" : "Certificado X.509 público del IdP",
    "Attribute mapping" : "Mapeo del atributo",
    "Security settings" : "Configuraciones de seguridad",
    "For increased security we recommend enabling the following settings if supported by your environment." : "Para mayor seguridad le recomendamos habilitar las siguientes configuraciones si están soportados en su ambiente.",
    "Signatures and encryption offered" : "Firmas y encripción disponibles",
    "Signatures and encryption required" : "Firmas y encripción requeridos",
    "Download metadata XML" : "Descargar metadatos XML",
    "Metadata invalid" : "Metadatos inválidos",
    "Metadata valid" : "Metadatos válidos",
    "Account not provisioned." : "La cuenta no está aprovisionada. ",
    "Your account is not provisioned, access to this service is thus not possible." : "Su cuenta no ha sido aprovisionada, por lo cual el acceso a este servico no es posible. ",
    "Indicates if the SP will validate all received XMLs." : "Indica si el SP validará todos los XMLs recibidos. ",
    "Only allow authentication if an account is existent on some other backend. (e.g. LDAP)" : "Sólo permitir autenticacion si la cuenta existe en algún otro sistema. (ejem. LDAP)",
    "Show Service Provider settings ..." : "Mostrar las configuraciones del proveedor de servicios ...",
    "Show optional Identity Provider settings ..." : "Mostrar las configuraciones opcionales para Proveedor de Identidad ...",
    "Show security settings ..." : "Mostrar las configuraciones de seguridad ...",
    "If you want to optionally map SAML attributes to the user you can configure these here." : "Si, de manera opcional, desdea mapear atributos SAML al usuario, los puede configurar aquí.",
    "Show attribute mapping settings ..." : "Mostrar las configuraciones del mapeo del atributo"
},
"nplurals=2; plural=(n != 1);");

==> v1.6.1.zip: user_saml/l10n/es_AR.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Guardado",
    "X.509 certificate of the Service Provider" : "certificado X.509 del Proveedor de Servicio",
    "Private key of the Service Provider" : "Llave privada del Proveedor de Servicio",
    "Indicates that the nameID of the <samlp:logoutRequest> sent by this SP will be encrypted." : "Indica que el nameID de <samlp:logoutRequest> enviado por este SP será encriptado. ",
    "Indicates whether the <samlp:AuthnRequest> messages sent by this SP will be signed. [Metadata of the SP will offer this info]" : "Indica si los mensajes <samlp:AuthnRequest> enviados por este SP serán firmados. [Los metadatos del SP proporcionarán esta información]",
    "Indicates whether the  <samlp:logoutRequest> messages sent by this SP will be signed." : "Indica si los mensjaes <samlp:logoutRequest> enviados por este SP serán firmados. ",
    "Indicates whether the  <samlp:logoutResponse> messages sent by this SP will be signed." : "Indica is los mensajes <samlp:logoutResponse> enviados por este SP serán firmados. ",
    "Whether the metadata should be signed." : "Si los metadatos deben ser firmados o no. ",
    "Indicates a requirement for the <samlp:Response>, <samlp:LogoutRequest> and <samlp:LogoutResponse> elements received by this SP to be signed." : "Indica un requerimiento para que los elementos recibidos <samlp:Response>, <samlp:LogoutRequest> y <samlp:LogoutResponse> por este SP sean firmados. ",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be signed. [Metadata of the SP will offer this info]" : "Indica un requerimientos para que los elementos recibidos <saml:Assertion> por este SP para ser firmados. [Los metadatos del SP proporcionarán esta información]",
    "Indicates a requirement for the <saml:Assertion> elements received by this SP to be encrypted." : "Indica un requerimiento para que los elelemtnos recibidos <saml:Assertion> de este SP sean encriptados. ",
    " Indicates a requirement for the NameID element on the SAMLResponse received by this SP to be present." : "Indica un requerimiento para que el elemento NameID en la SAMLResponse recibida por este SP esté presente. ",
    "Indicates a requirement for the NameID received by this SP to be encrypted." : "Indica que un requerimiento para el NameID recibido por este SP está encriptado.",
    "ADFS URL-Encodes SAML data as lowercase, and the toolkit by default uses uppercase. Enable for ADFS compatibility on signature verification." : "ADFS URL-Codifica los datos SAML como minúsculas, y el juego de herramientas usa mayúsculas por defecto. Habilite para tener compatibilidad con ADFS en la verificacón de la firma.",
    "Attribute to map the UID to." : "Atributo a mapear al UID.",
    "Attribute to map the displayname to." : "Atributo a mapear a displayname. ",
    "Attribute to map the email address to." : "Atributo a mapear a email address.",
    "Use SAML auth for the %s desktop clients (requires user re-authentication)" : "Favor de usar autenticación SAML para los %s clientes de escritorio (se requiere volver a autenticar)",
    "SSO & SAML authentication" : "Autenticación SSO & SAML",
    "Open documentation" : "Abrir documentación",
    "Please choose whether you want to authenticate using the SAML provider built-in in Nextcloud or whether you want to authenticate against an environment variable." : "Favor de seleccionar si usted desdea autenticarse usando el proveedor integrado SAML de Nextcloud o si desdea autenticarse contra una variable de ambiente.  ",
    "Use built-in SAML authentication" : "Usar autenticación SAML integrada",
    "Use environment variable" : "Usar la variable de ambiente",
    "General" : "General",
    "Service Provider Data" : "Datos del Proveedor de Servicio",
    "If your Service Provider should use certificates you can optionally specify them here." : "Si su Proveedor de Servicio debe usar certificados, usted puede especificarlos opcionalmente desde aquí.",
    "Identity Provider Data" : "Datos del Proveedor de Identidad",
    "Configure your IdP settings here." : "Configure los configuraciones de IdP aquí. ",
    "Identifier of the IdP entity (must be a URI)" : "Identificador de la entidad IdP (debe ser un URI)",
    "URL Target of the IdP where the SP will send the Authentication Request Message" : "URL Destino del IdP donde el SP enviará automaticamente el Mensaje de Solicitud de Autenticación",
    "URL Location of the IdP where the SP will send the SLO Request" : "Ubicación del URL del IdP donde el SP enviará la Solicitud SLO",
    "Public X.509 certificate of the IdP" : "Certificado X.509 público del IdP",
    "Attribute mapping" : "Mapeo del atributo",
    "Security settings" : "Configuraciones de seguridad",
    "For increased security we recommend enabling the following settings if supported by your environment." : "Para mayor seguridad le recomendamos habilitar las siguientes configuraciones si están soportados en su ambiente.",
    "Signatures and encryption offered" : "Firmas y encripción disponibles",
    "Signatures and encryption required" : "Firmas y encripción requeridos",
    "Download metadata XML" : "Descargar metadatos XML",
    "Metadata invalid" : "Metadatos inválidos",
    "Metadata valid" : "Metadatos válidos",
    "Account not provisioned." : "La cuenta no está aprovisionada. ",
    "Your account is not provisioned, access to this service is thus not possible." : "Su cuenta no ha sido aprovisionada, por lo cual el acceso a este servico no es posible. ",
    "Indicates if the SP will validate all received XMLs." : "Indica si el SP validará todos los XMLs recibidos. ",
    "Only allow authentication if an account is existent on some other backend. (e.g. LDAP)" : "Sólo permitir autenticacion si la cuenta existe en algún otro sistema. (ejem. LDAP)",
    "Make sure to configure an administrative user that can access the instance via SSO. Logging-in with your regular %s account won't be possible anymore." : "Asegurese de configurar un usuario administrativo que tenga acceso a la instancia mediante SSO. Iniciar sesión con su cuenta regular %s no será más posible. ",
    "Show Service Provider settings ..." : "Mostrar las configuraciones del proveedor de servicios ...",
    "Show optional Identity Provider settings ..." : "Mostrar las configuraciones opcionales para Proveedor de Identidad ...",
    "If you want to optionally map SAML attributes to the user you can configure these here." : "Si, de manera opcional, desdea mapear atributos SAML al usuario, los puede configurar aquí.",
    "Show attribute mapping settings ..." : "Mostrar las configuraciones del mapeo del atributo",
    "Show security settings ..." : "Mostrar las configuraciones de seguridad ..."
},
"nplurals=2; plural=(n != 1);");
